==> archimedes-1.2.0.tar.gz: archimedes-1.2.0/src/GaAs.h <==
/* GaAs.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 24 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// conduction band calculated using the model : sp3s* (see Vogl)
// data interpolated by a fourth order polynomial


CB_FULL[GAAS][0]=-3.1317e+06;
CB_FULL[GAAS][1]=2.6727e+10;
CB_FULL[GAAS][2]=-9.6101e+09;
CB_FULL[GAAS][3]=-4.2989e+11;
CB_FULL[GAAS][4]=-1.1049e+13;
CB_FULL[GAAS][5]=1.6919e+11;
CB_FULL[GAAS][6]=1.7148e+09;
CB_FULL[GAAS][7]=-4.0471e+07;
CB_FULL[GAAS][8]=1.6350e+05;
CB_FULL[GAAS][9]=1.6454e+02;
CB_FULL[GAAS][10]=1.5214e+00;

==> archimedes-2.0.0.tar.gz: archimedes-2.0.0/src/GaAs.h <==
/* GaAs.h -- This file is part of Archimedes release 1.2.0
   Archimedes is a simulator for Submicron and Nanoscaled
   2D III-V Semiconductor Devices.

   Copyright (C) 2004-2011 Jean Michel Sellier
   <jeanmichel.sellier@gmail.com>
   <jsellier@purdue.edu>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


// ######################################################
// Created on 22 aug.2011, Carry le Rouet, France J.M.Sellier
// Last modif. : 31 Aug.2011, Carry le Rouet, J.M.Sellier
// ######################################################

// conduction band calculated using the model : sp3s* (see Vogl)
// data interpolated by a fourth order polynomial

// Parabolic conduction band
// Gamma valley 100-direction
CB_FULL[GAAS][0]=-1.3608e+22;
CB_FULL[GAAS][1]=+7.0716e+20;
CB_FULL[GAAS][2]=-1.5540e+19;
CB_FULL[GAAS][3]=+1.8813e+17;
CB_FULL[GAAS][4]=-1.3673e+15;
CB_FULL[GAAS][5]=+6.0685e+12;
CB_FULL[GAAS][6]=-1.5861e+10;
CB_FULL[GAAS][7]=+2.1777e+07;
CB_FULL[GAAS][8]=+2.2438e+07;
CB_FULL[GAAS][9]=-1.3451;
CB_FULL[GAAS][10]=0.0; // 8.6584e-004
